==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputDescriptionMetadata.a == null) {
                ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
            }
            if (a.k(ToolActionNumberInputDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionNumberInputDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionNumberInputDescriptionMetadata.b(a);
            a.ac("ToolActionNumberInput", () => new ToolActionNumberInputDescription());
            a.ab("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ToolActionNumberInputDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionNumberInputDescription } from "./ToolActionNumberInputDescription";
/**
 * @hidden
 */
export let ToolActionNumberInputDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionNumberInputDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionNumberInputDescriptionMetadata.a == null) {
                ToolActionNumberInputDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionNumberInputDescriptionMetadata.c(ToolActionNumberInputDescriptionMetadata.a);
            }
            if (a.k(ToolActionNumberInputDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionNumberInputDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
            a.item("Value", "Number:double");
        }
        static d(a) {
            ToolActionNumberInputDescriptionMetadata.b(a);
            a.ae("ToolActionNumberInput", () => new ToolActionNumberInputDescription());
            a.ad("ToolActionNumberInput", ToolActionNumberInputDescriptionMetadata.a);
        }
    }
    ToolActionNumberInputDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionNumberInputDescriptionMetadata, 'ToolActionNumberInputDescriptionMetadata');
    ToolActionNumberInputDescriptionMetadata.a = null;
    return ToolActionNumberInputDescriptionMetadata;
})();
